@@ -1,13 +1,4 @@
-use actix::prelude::*;
-use actix::{Actor, ActorContext, AsyncContext, Addr, Handler, StreamHandler};
-use actix_http::ws::Codec;
-use actix_http::ResponseBuilder;
-use actix_web::{web, get, middleware, App, Error, HttpRequest, HttpResponse, HttpServer, Responder};
-use actix_web_actors::ws;
-use serde::Deserialize;
-use lazy_static::lazy_static;
-use std::sync::{Arc, RwLock};
-use std::collections::{HashMap, HashSet};
+use actix_web::{get, middleware, App, HttpRequest, HttpServer, Responder};
 use simple_logger::SimpleLogger;
 
 /// Entry point for index
